@@ -35,6 +35,29 @@ def load_library():
     return ctypes.CDLL(libpath)
 
 
+if not hasattr(ctypes, 'c_ssize_t'):
+    if ctypes.sizeof(ctypes.c_uint) == ctypes.sizeof(ctypes.c_void_p):
+        ctypes.c_ssize_t = ctypes.c_int
+    elif ctypes.sizeof(ctypes.c_ulong) == ctypes.sizeof(ctypes.c_void_p):
+        ctypes.c_ssize_t = ctypes.c_long
+    elif ctypes.sizeof(ctypes.c_ulonglong) == ctypes.sizeof(ctypes.c_void_p):
+        ctypes.c_ssize_t = ctypes.c_longlong
+
+
+class MagickPixelPacket(ctypes.Structure):
+
+    _fields_ = [('storage_class', ctypes.c_int),
+                ('colorspace', ctypes.c_int),
+                ('matte', ctypes.c_int),
+                ('fuzz', ctypes.c_double),
+                ('depth', ctypes.c_size_t),
+                ('red', ctypes.c_double),
+                ('green', ctypes.c_double),
+                ('blue', ctypes.c_double),
+                ('opacity', ctypes.c_double),
+                ('index', ctypes.c_double)]
+
+
 #: (:class:`ctypes.CDLL`) The MagickWand library.
 library = load_library()
 
@@ -61,6 +84,9 @@ library.MagickReadImage.argtypes = [ctypes.c_void_p, ctypes.c_char_p]
 
 library.MagickReadImageFile.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
 
+library.MagickGetImageFormat.argtypes = [ctypes.c_void_p]
+library.MagickGetImageFormat.restype = ctypes.c_char_p
+
 library.MagickSetImageFormat.argtypes = [ctypes.c_void_p, ctypes.c_char_p]
 
 library.MagickGetImageBlob.argtypes = [ctypes.c_void_p,
@@ -134,6 +160,10 @@ library.PixelClearException.argtypes = [ctypes.c_void_p]
 library.IsPixelWandSimilar.argtypes = [ctypes.c_void_p, ctypes.c_void_p,
                                        ctypes.c_double]
 
+library.PixelGetMagickColor.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
+
+library.PixelSetMagickColor.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
+
 library.PixelSetColor.argtypes = [ctypes.c_void_p, ctypes.c_char_p]
 
 library.PixelGetColorAsString.argtypes = [ctypes.c_void_p]
