@@ -19,7 +19,7 @@ import sys
 import warnings
 import platform
 from . import exceptions
-from .api import library, libc
+from .api import library, libc, MagickPixelPacket
 from .resource import (increment_refcount, decrement_refcount, Resource,
                        DestroyedResourceError)
 from .color import Color
@@ -296,6 +296,50 @@ class Image(Resource):
         """(:class:`tuple`) The pair of (:attr:`width`, :attr:`height`)."""
         return self.width, self.height
 
+    @property
+    def format(self):
+        """(:class:`basestring`) The image format.
+
+        If you want to convert the image format, just reset this property::
+
+            assert isinstance(img, wand.image.Image)
+            img.format = 'png'
+
+        It may raise :exc:`ValueError` when the format is unsupported.
+
+        """
+        fmt = library.MagickGetImageFormat(self.wand)
+        if fmt:
+            return fmt
+        self.raise_exception()
+
+    @format.setter
+    def format(self, fmt):
+        if not isinstance(fmt, basestring):
+            raise TypeError("format must be a string like 'png' or 'jpeg'"
+                            ', not ' + repr(fmt))
+        r = library.MagickSetImageFormat(self.wand, fmt.strip().upper())
+        if not r:
+            raise ValueError(repr(fmt) + ' is unsupported format')
+
+    def convert(self, format):
+        """Converts the image format with the original image maintained.
+        It returns a converted image instance which is new. ::
+
+            with img.convert('png') as converted:
+                converted.save(filename='converted.png')
+
+        :param format: image format to convert to
+        :type format: :class:`basestring`
+        :returns: a converted image
+        :rtype: :class:`Image`
+        :raises: :exc:`ValueError` when the given ``format`` is unsupported
+
+        """
+        cloned = self.clone()
+        cloned.format = format
+        return cloned
+
     def resize(self, width=None, height=None, filter='triangle', blur=1):
         """Resizes the image.
 
@@ -391,13 +435,8 @@ class Image(Resource):
 
         """
         if format is not None:
-            if not isinstance(format, basestring):
-                raise TypeError("format must be a string like 'png' or 'jpeg'"
-                                ', not ' + repr(format))
-            r = library.MagickSetImageFormat(self.wand,
-                                             str(format).strip().upper())
-            if not r:
-                raise ValueError('{0!r} is an invalid format'.format(format))
+            with self.convert(format) as converted:
+                return converted.make_blob()
         library.MagickResetIterator(self.wand)
         length = ctypes.c_size_t()
         blob_p = library.MagickGetImageBlob(self.wand, ctypes.byref(length))
@@ -479,15 +518,19 @@ class Iterator(Resource, collections.Iterator):
         width = ctypes.c_size_t()
         pixels = library.PixelGetNextIteratorRow(self.resource,
                                                  ctypes.byref(width))
-        get_color = library.PixelGetColorAsString
+        get_color = library.PixelGetMagickColor
+        struct_size = ctypes.sizeof(MagickPixelPacket)
         if x is None:
             r_pixels = [None] * width.value
             for x in xrange(width.value):
                 pc = pixels[x]
-                c = get_color(pc)
-                r_pixels[x] = Color(c)
+                packet_buffer = ctypes.create_string_buffer(struct_size)
+                get_color(pc, packet_buffer)
+                r_pixels[x] = Color(raw=packet_buffer)
             return r_pixels
-        return Color(get_color(pixels[x]))
+        packet_buffer = ctypes.create_string_buffer(struct_size)
+        get_color(pixels[x], packet_buffer)
+        return Color(raw=packet_buffer)
 
     def clone(self):
         """Clones the same iterator."""
